//
//  View.m
//  Pinch
//
//  Created by NYU User on 11/3/11.
//  Copyright (c) 2011 __MyCompanyName__. All rights reserved.
//

#import "View.h"

@implementation View

- (id) initWithFrame: (CGRect) frame
{
	self = [super initWithFrame: frame];
	if (self) {
		// Initialization code
		self.backgroundColor = [UIColor whiteColor];
		self.multipleTouchEnabled = YES;
		distance = self.bounds.size.width / 3;
		verdict = @"neither";
	}
	return self;
}


- (void) touchesMoved: (NSSet *) touches withEvent: (UIEvent *) event {
	if (touches.count == 2) {
		NSArray *array = touches.allObjects;	//Copy the set into an array.
		UITouch *touch0 = [array objectAtIndex: 0];
		UITouch *touch1 = [array objectAtIndex: 1];

		CGPoint current0 = [touch0 locationInView: self];
		CGPoint current1 = [touch1 locationInView: self];

		CGPoint previous0 = [touch0 previousLocationInView: self];
		CGPoint previous1 = [touch1 previousLocationInView: self];

		CGFloat dx = current0.x - current1.x;
		CGFloat dy = current0.y - current1.y;
		CGFloat currentDistance = hypotf(dx, dy);

		dx = previous0.x - previous1.x;
		dy = previous0.y - previous1.y;
		CGFloat previousDistance = hypotf(dx, dy);

		if (currentDistance > previousDistance) {
			verdict = @"spread";
		} else if (currentDistance < previousDistance) {
			verdict = @"pinch";
		} else {
			verdict = @"neither";
		}

		//If ratio > 1, the distance is widening.
		if (previousDistance > 0) {
			CGFloat ratio = currentDistance / previousDistance;
			distance *= ratio;		//means distance = distance * ratio;
		} else {
			distance = currentDistance;
		}

		[self setNeedsDisplay];	//Trigger a call to drawRect:.
	}
}


// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.

- (void) drawRect: (CGRect) rect
{
    // Drawing code
	NSString *string =
		[NSString stringWithFormat: @"%@ %d", verdict, (int)distance];
	UIFont *font = [UIFont systemFontOfSize: distance / 2];

	//Center the string in the view.
	CGSize size = [string sizeWithFont: font];
	CGRect b = self.bounds;
	CGFloat x = b.origin.x + (b.size.width - size.width) / 2;
	CGFloat y = b.origin.y + (b.size.height - size.height) / 2;
	[string drawAtPoint: CGPointMake(x, y) withFont: font];
}


@end
